@@ -1,3 +1,5 @@
+#include "recentdocuments.h"
+
 #include <QCoreApplication>
 #include <QDBusInterface>
 #include <QFileInfo>
@@ -9,11 +11,10 @@
 #include <KDesktopFile>
 #include <KIO/Job>
 #include <KLocalizedString>
+#include <KProtocolManager>
 
 #include <stdio.h>
 
-#include "recentdocuments.h"
-
 extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
     // necessary to use other kio slaves
@@ -77,7 +78,12 @@ void RecentDocuments::listDir(const QUrl& url)
 
                 QUrl urlInside(file.readUrl());
                 QString toDisplayString = urlInside.toDisplayString();
-                if (urlInside.scheme() == "recentdocuments" || urlSet.contains(toDisplayString))
+
+                // Filter out things that can't be viewed in a file manager because they don't
+                // meet the user definition of a file for the purpose of "recently accessed files"
+                if (urlInside.scheme() == "recentdocuments"
+                    || !KProtocolManager::supportsListing(urlInside)
+                    || urlSet.contains(toDisplayString))
                     continue;
 
                 KIO::UDSEntry uds;
