@@ -64,6 +64,7 @@
 #include <kio/previewjob.h>
 
 #include <iostream>
+#include <limits>
 #include <QDirIterator>
 
 // Use correctly KComponentData instead of KApplication (but then no QPixmap)
@@ -86,6 +87,10 @@
 // plugin       - the name of the plugin library to be used for thumbnail creation.
 //                Provided by the application to save an addition KTrader
 //                query here.
+// enabledPlugins - a list of enabled thumbnailer plugins. PreviewJob does not call
+//                  this thumbnail slave when a given plugin isn't enabled. However,
+//                  for directory thumbnails it doesn't know that the thumbnailer
+//                  internally also loads the plugins.
 // shmid        - the shared memory segment id to write the image's data to.
 //                The segment is assumed to provide enough space for a 32-bit
 //                image sized width x height pixels.
@@ -107,6 +112,9 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
 #ifdef USE_KINSTANCE
     KComponentData componentData("kio_thumbnail");
 #else
+
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
+
     // creating KApplication in a slave in not a very good idea,
     // as dispatchLoop() doesn't allow it to process its messages,
     // so it for example wouldn't reply to ksmserver - on the other
@@ -150,6 +158,11 @@ ThumbnailProtocol::~ThumbnailProtocol()
 void ThumbnailProtocol::get(const QUrl &url)
 {
     m_mimeType = metaData("mimeType");
+    m_enabledPlugins = metaData("enabledPlugins").split(QLatin1Char(','), QString::SkipEmptyParts);
+    if (m_enabledPlugins.isEmpty()) {
+        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
+        m_enabledPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
+    }
     //qDebug() << "Wanting MIME Type:" << m_mimeType;
 #ifdef THUMBNAIL_HACK
     // ### HACK
@@ -453,7 +466,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
-        m_maxFileSize = globalConfig.readEntry("MaximumSize", qulonglong(5 * 1024 * 1024)); // 5 MByte default
+        m_maxFileSize = globalConfig.readEntry("MaximumSize", std::numeric_limits<qint64>::max());
     }
 
     const int tiles = 2; //Count of items shown on each dimension
@@ -515,18 +528,6 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
 
     const int maxYPos = folderHeight - bottomMargin - segmentHeight;
 
-    // Setup image object for preview with only one tile
-    QImage oneTileImg(folder.size(), QImage::Format_ARGB32);
-    oneTileImg.fill(0);
-
-    QPainter oneTilePainter(&oneTileImg);
-    oneTilePainter.setCompositionMode(QPainter::CompositionMode_Source);
-    oneTilePainter.drawPixmap(0, 0, folder);
-    oneTilePainter.setCompositionMode(QPainter::CompositionMode_SourceOver);
-
-    const int oneTileWidth = folderWidth - leftMargin - rightMargin;
-    const int oneTileHeight = folderHeight - topMargin - bottomMargin;
-
     int validThumbnails = 0;
 
     while ((skipped <= skipValidItems) && (yPos <= maxYPos) && validThumbnails == 0) {
@@ -558,10 +559,6 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
                 continue;
             }
 
-            if (validThumbnails == 0) {
-                drawSubThumbnail(oneTilePainter, dir.filePath(), oneTileWidth, oneTileHeight, xPos, yPos, frameWidth);
-            }
-
             if (skipped < skipValidItems) {
                 ++skipped;
                 continue;
@@ -617,8 +614,20 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
         img = QImage();
     }
 
-    // If only for one file a thumbnail could be generated then use image with only one tile
+    // If only for one file a thumbnail could be generated then paint an image with only one tile
     if (validThumbnails == 1) {
+        QImage oneTileImg(folder.size(), QImage::Format_ARGB32);
+        oneTileImg.fill(0);
+
+        QPainter oneTilePainter(&oneTileImg);
+        oneTilePainter.setCompositionMode(QPainter::CompositionMode_Source);
+        oneTilePainter.drawPixmap(0, 0, folder);
+        oneTilePainter.setCompositionMode(QPainter::CompositionMode_SourceOver);
+
+        const int oneTileWidth = folderWidth - leftMargin - rightMargin;
+        const int oneTileHeight = folderHeight - topMargin - bottomMargin;
+
+        drawSubThumbnail(oneTilePainter, hadFirstThumbnail, oneTileWidth, oneTileHeight, leftMargin, topMargin, frameWidth);
         return oneTileImg;
     }
 
@@ -668,11 +677,6 @@ const QImage ThumbnailProtocol::getIcon()
 bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& filePath,
                                            int segmentWidth, int segmentHeight)
 {
-    if (m_enabledPlugins.isEmpty()) {
-        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-        m_enabledPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
-    }
-
     const QMimeDatabase db;
     const QUrl fileUrl = QUrl::fromLocalFile(filePath);
     const QString subPlugin = pluginForMimeType(db.mimeTypeForUrl(fileUrl).name());
